==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/dialogs/dlgeditaction.h <==
/***************************************************************************
                          dlgeditaction.h  -  Edit Action
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : St nov 6 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@host.sk
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGEDITACTION_H
#define DLGEDITACTION_H

#include <qwidget.h>
#include <qcheckbox.h>
#include <kdialogbase.h>

/**
DIalog used to edit an action (in toolbar).
  *@author Tomas Mecir
  */

class cAction;

class KLineEdit;
class KIconButton;

class dlgEditAction : public KDialogBase  {
   Q_OBJECT
public: 
  dlgEditAction (cAction *a, QWidget *parent=0, const char *name=0);
  ~dlgEditAction ();
  bool showMe ();
protected:
  void createDialog ();

  cAction *action;

  //widgets
  KLineEdit *label, *cmd, *cmd2;
  KIconButton *icon;
  QCheckBox *toggler;
  
protected slots:
  void updateActionDialog(bool how);
};

#endif

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/dialogs/dlgeditaction.h <==
/***************************************************************************
                          dlgeditaction.h  -  Edit Action
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : St nov 6 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLGEDITACTION_H
#define DLGEDITACTION_H

#include <qwidget.h>
#include <qcheckbox.h>
#include <kdialogbase.h>

/**
DIalog used to edit an action (in toolbar).
  *@author Tomas Mecir
  */

class cAction;

class KLineEdit;
class KIconButton;

class dlgEditAction : public KDialogBase  {
   Q_OBJECT
public: 
  dlgEditAction (cAction *a, QWidget *parent=0, const char *name=0);
  ~dlgEditAction ();
  bool showMe ();
protected:
  void createDialog ();

  cAction *action;

  //widgets
  KLineEdit *label, *cmd, *cmd2;
  KIconButton *icon;
  QCheckBox *toggler;
  
protected slots:
  void updateActionDialog(bool how);
};

#endif
